#[unsafe(no_mangle)]pub unsafe extern "C" fn yinput_yxmltext(str: *mut c_char) -> YInputExpand description
Function constructor used to create a nested YXmlText YInput cell prefilled with a specified
string, which must be a null-terminated UTF-8 character pointer.
This function doesn’t allocate any heap resources and doesn’t release any on its own, therefore its up to a caller to free resources once a structure is no longer needed.