yundo_manager

Function yundo_manager 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn yundo_manager( options: *const YUndoManagerOptions, ) -> *mut YUndoManager
Creates a new instance of undo manager bound to a current doc. It can be used to track specific shared refs via yundo_manager_add_scope and updates coming from specific origin

  • like ability to undo/redo operations originating only at the local peer - by using yundo_manager_add_origin.

This object can be deallocated via yundo_manager_destroy.