yxmltext_insert_attr

Function yxmltext_insert_attr 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn yxmltext_insert_attr( txt: *const Branch, txn: *mut Transaction, attr_name: *const c_char, attr_value: *const YInput, )
Inserts an XML attribute described using attr_name and attr_value. If another attribute with the same name already existed, its value will be replaced with a provided one.

Both attr_name and attr_value must be a null-terminated UTF-8 encoded strings. Their contents are being copied, therefore it’s up to a function caller to properly release them.