#[repr(C)]pub struct YAfterTransactionEvent {
pub before_state: YStateVector,
pub after_state: YStateVector,
pub delete_set: YIdSet,
}Expand description
Event generated for callbacks subscribed using ydoc_observe_after_transaction. It contains
snapshot of changes made within any committed transaction.
Fields
before_state: YStateVectorDescriptor of a document state at the moment of creating the transaction.
after_state: YStateVectorDescriptor of a document state at the moment of committing the transaction.
delete_set: YIdSetInformation about all items deleted within the scope of a transaction.