pub struct Event { /* private fields */ }Expand description
Event type emitted by an Awareness struct.
Implementations
Sourceimpl Event
impl Event
pub fn new( added: Vec<ClientID>, updated: Vec<ClientID>, removed: Vec<ClientID>, ) -> Self
pub fn summary(&self) -> &AwarenessUpdateSummary
Sourcepub fn added(&self) -> &[ClientID]
pub fn added(&self) -> &[ClientID]
Collection of new clients that have been added to an Awareness struct, that was not known
before. Actual client state can be accessed via awareness.clients().get(client_id).
Sourcepub fn updated(&self) -> &[ClientID]
pub fn updated(&self) -> &[ClientID]
Collection of new clients that have been updated within an Awareness struct since the last
update. Actual client state can be accessed via awareness.clients().get(client_id).
Sourcepub fn removed(&self) -> &[ClientID]
pub fn removed(&self) -> &[ClientID]
Collection of new clients that have been removed from Awareness struct since the last update.
Sourcepub fn all_changes(&self) -> Vec<ClientID>
pub fn all_changes(&self) -> Vec<ClientID>
Returns all the changed client IDs (added, updated and removed) combined.