pub enum EntryChange {
Inserted(Out),
Updated(Out, Out),
Removed(Out),
}Expand description
A single change done over a map-component of shared data type.
Variants
Inserted(Out)
Informs about a new value inserted under specified entry.
Updated(Out, Out)
Informs about a change of old value (1st field) to a new one (2nd field) under a corresponding entry.
Removed(Out)
Informs about a removal of a corresponding entry - contains a removed value.