#[repr(transparent)]pub struct Root<S> {
pub name: Arc<str>,
/* private fields */
}Expand description
A logical reference to a root-level shared collection. It can be shared across different documents to reference the same logical type.
Example
use yrs::{Doc, RootRef, SharedRef, TextRef, Transact};
let root = TextRef::root("hello");
let doc1 = Doc::new();
let txt1 = root.get_or_create(&mut doc1.transact_mut());
let doc2 = Doc::new();
let txt2 = root.get_or_create(&mut doc2.transact_mut());
// instances of TextRef point to different heap objects
assert_ne!(&txt1 as *const _, &txt2 as *const _);
// logical descriptors of both TextRef are the same as they refer to the
// same logical entity
assert_eq!(txt1.hook(), txt2.hook());Fields
name: Arc<str>Unique identifier of root-level shared collection.
Implementations
Sourceimpl<S: RootRef> Root<S>
impl<S: RootRef> Root<S>
Sourcepub fn new<N: Into<Arc<str>>>(name: N) -> Self
pub fn new<N: Into<Arc<str>>>(name: N) -> Self
Creates a new logical reference for a root-level shared collection of a given name and type. Returned value can be used to resolve instances of root-level types by calling Root::get or Root::get_or_create.
Sourcepub fn get_or_create<T: WriteTxn>(&self, txn: &mut T) -> S
pub fn get_or_create<T: WriteTxn>(&self, txn: &mut T) -> S
Returns a reference to a shared root-level collection current Root represents, or creates it if it wasn’t instantiated before.