#[unsafe(no_mangle)]pub unsafe extern "C" fn youtput_read_string(
val: *const YOutput,
) -> *mut c_charExpand description
Attempts to read the value for a given YOutput pointer as a null-terminated UTF-8 encoded
string.
Returns a null pointer in case when a value stored under current YOutput cell
is not a string. Underlying string is released automatically as part of youtput_destroy
destructor.